@@ -3,10 +3,12 @@ from django.contrib.auth.models import (
     AbstractUser as DjangoAbstractUser,
     PermissionsMixin,
 )
+from django.db.models.options import Options
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from swap_user.managers.email import Manager
+from swap_user.settings import swap_user_settings
 
 
 class AbstractEmailUser(PermissionsMixin, DjangoAbstractBaseUser):
@@ -59,10 +61,39 @@ class AbstractEmailUser(PermissionsMixin, DjangoAbstractBaseUser):
     get_full_name = __str__
 
 
-class EmailUser(AbstractEmailUser):
+class AbstractNamedEmailUser(AbstractEmailUser):
     """
-    Point on this model if you want drop off EmailUser model with `email` field.
+    Use this abstract class if you want to add a user with
+    first name and last name.
     """
 
+    first_name = models.CharField(
+        verbose_name=_("first name"),
+        max_length=50,
+        # maybe remove
+        blank=True,
+    )
+    last_name = models.CharField(
+        verbose_name=_("last name"),
+        max_length=100,
+        # maybe remove
+        blank=True,
+    )
+
     class Meta:
-        swappable = "AUTH_USER_MODEL"
+        abstract = True
+
+    def __str__(self):
+        return f"{self.first_name} {self.last_name}"
+
+
+class Meta:
+    swappable = "AUTH_USER_MODEL"
+
+
+base_classes = (swap_user_settings.EMAIL_USER_ABSTRACT_BASE_CLASS,)
+EmailUser = type("EmailUser", base_classes, {
+    "_meta": Options(Meta, app_label="swap_user"),
+    "__module__": "swap_user.models",
+    "__doc__": '\n    Point on this model if you want drop off EmailUser model with `email` field.\n    ',
+})
